==> qtjambi-sql-debuginfo-macos-6.5.7.jar: sources/QtJambiSql/QSqlQueryModel_shell.h <==
#ifndef QSQLQUERYMODEL_SHELL_H
#define QSQLQUERYMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtsql-config.h>
#if QT_CONFIG(sqlmodel)
#include <QtSql/qsqlquerymodel.h>
#endif //QT_CONFIG(sqlmodel)
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sqlmodel)

class QSqlQueryModel_shell : public QSqlQueryModel, public QtJambiShellInterface
{
public:
    QSqlQueryModel_shell(QObject* parent0 = nullptr);
    ~QSqlQueryModel_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QSqlQueryModel_mshell;
    friend class QSqlQueryModel_oshell;
};


class QSqlQueryModel_mshell : public QSqlQueryModel_shell
{
public:
    using QSqlQueryModel_shell::QSqlQueryModel_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSqlQueryModel_oshell : public QSqlQueryModel_mshell
{
public:
    using QSqlQueryModel_mshell::QSqlQueryModel_mshell;
    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    bool clearItemData(const QModelIndex& index0) override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& item0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    QModelIndex indexInQuery(const QModelIndex& item0) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    void multiData(const QModelIndex& index0, QModelRoleDataSpan roleDataSpan1) const override;
    void queryChange() override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void resetInternalData() override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlQueryModel_access : public QSqlQueryModel
{
    void __qt_beginInsertColumns_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginInsertRows_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginRemoveColumns_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginRemoveRows_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginResetModel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endInsertColumns(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endInsertRows(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endRemoveColumns(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endRemoveRows(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endResetModel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID error0);
    jboolean __qt_canFetchMore_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_columnCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint role1) const;
    void __qt_fetchMore_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_indexInQuery_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jboolean __qt_insertColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    void __qt_queryChange(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jobject __qt_roleNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setHeaderData_int_Qt_Orientation_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jobject value2, jint role3);
};

#endif // QT_CONFIG(sqlmodel)
#endif // QSQLQUERYMODEL_SHELL_H

==> qtjambi-sql-debuginfo-macos-6.6.1.jar: sources/QtJambiSql/QSqlQueryModel_shell.h <==
#ifndef QSQLQUERYMODEL_SHELL_H
#define QSQLQUERYMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtsql-config.h>
#if QT_CONFIG(sqlmodel)
#include <QtSql/qsqlquerymodel.h>
#endif //QT_CONFIG(sqlmodel)
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/JavaAPI>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sqlmodel)

class QSqlQueryModel_shell : public QSqlQueryModel, public QtJambiShellInterface
{
public:
    QSqlQueryModel_shell(QObject* parent0 = nullptr);
    ~QSqlQueryModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    bool clearItemData(const QModelIndex& index0) override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& item0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    QModelIndex indexInQuery(const QModelIndex& item0) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    void multiData(const QModelIndex& index0, QModelRoleDataSpan roleDataSpan1) const override;
    void queryChange() override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void resetInternalData() override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlQueryModel_access : public QSqlQueryModel
{
    void __qt_beginInsertColumns_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginInsertRows_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginRemoveColumns_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginRemoveRows_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint first1, jint last2);
    void __qt_beginResetModel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endInsertColumns(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endInsertRows(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endRemoveColumns(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endRemoveRows(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_endResetModel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID error0);
    jboolean __qt_canFetchMore_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_columnCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint role1) const;
    void __qt_fetchMore_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_indexInQuery_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jboolean __qt_insertColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    void __qt_queryChange(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jobject __qt_roleNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setHeaderData_int_Qt_Orientation_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jobject value2, jint role3);
};

#endif // QT_CONFIG(sqlmodel)
#endif // QSQLQUERYMODEL_SHELL_H
